@@ -8,7 +8,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2020 by Thomas Dreibholz
+ * Copyright (C) 2002-2021 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -435,8 +435,9 @@ static bool createPolicyParameter(struct RSerPoolMessage*          message,
           if(plu == NULL) {
              return(false);
           }
-          plu->pp_plu_policy = htonl(poolPolicySettings->PolicyType);
-          plu->pp_plu_load   = htonl(poolPolicySettings->Load);
+          plu->pp_plu_policy  = htonl(poolPolicySettings->PolicyType);
+          plu->pp_plu_load    = htonl(poolPolicySettings->Load);
+          plu->pp_plu_loaddeg = htonl(poolPolicySettings->LoadDegradation);
        break;
       case PPT_PRIORITY_LEASTUSED_DEGRADATION:
           plud = (struct rserpool_policy_priority_leastused_degradation*)getSpace(message, sizeof(struct rserpool_policy_priority_leastused_degradation));
@@ -469,8 +470,9 @@ static bool createPolicyParameter(struct RSerPoolMessage*          message,
           if(rplu == NULL) {
              return(false);
           }
-          rplu->pp_rplu_policy = htonl(poolPolicySettings->PolicyType);
-          rplu->pp_rplu_load   = htonl(poolPolicySettings->Load);
+          rplu->pp_rplu_policy  = htonl(poolPolicySettings->PolicyType);
+          rplu->pp_rplu_load    = htonl(poolPolicySettings->Load);
+          rplu->pp_rplu_loaddeg = htonl(poolPolicySettings->LoadDegradation);
        break;
       case PPT_RANDOMIZED_PRIORITY_LEASTUSED_DEGRADATION:
           rplud = (struct rserpool_policy_randomized_priority_leastused_degradation*)getSpace(message, sizeof(struct rserpool_policy_randomized_priority_leastused_degradation));
